@@ -9,5 +9,5 @@ use common::method::eq::*;
 #[test]
 fn can_serialize_rc() {
     const LEN: usize = 8;
-    test_serialize_exact::<Rc<u64>, LEN>(&Rc::new(u64::MIN));
+    test_serialize_exact::<Rc<u64>, LEN>(Rc::new(u64::MIN));
 }
\ No newline at end of file
